package com.aliyun.videolistbyplayer;

import android.content.Context;

import com.aliyun.videolistbyplayer.adapter.RecyclerViewAdapter;
import com.aliyun.videolistbyplayer.bean.ListVideoBean;
import com.aliyun.videolistbyplayer.player.AliPlayerPool;
import com.aliyun.videolistbyplayer.player.AliPlayerPreload;

import java.util.LinkedList;


public class ListPlayerController{

    private static final ListPlayerModel mListPlayerModel = new ListPlayerModel();
    private static final int BUFFER_POSITION = 5000;
    private boolean mIsPreloading = false;
    private final AliPlayerPreload mAliPlayerPreload;
    private int mCurrentPosition;
    //Play the 0 th video for the first time
    private boolean isOnCreate;

    public ListPlayerController(Context context){
        isOnCreate = true;
        mAliPlayerPreload = AliPlayerPreload.getInstance();
        mAliPlayerPreload.setUrls(mListPlayerModel.getData());
    }

    /**
     * load assets/videolist.txt
     */
    public static void init(Context context) {
        mListPlayerModel.loadData(context.getApplicationContext());
    }

    /**
     * get Data Source
     */
    public LinkedList<ListVideoBean> getData(){
        return mListPlayerModel.getData();
    }

    public void changeSource(int position) {
        this.mCurrentPosition = position;
        mIsPreloading = false;
    }

    public void onPrepared(int position,RecyclerViewAdapter.RecyclerViewHolder viewHolder) {
        if (position == 0 && isOnCreate) {
            viewHolder.getAliPlayer().start();
            isOnCreate = false;
        }
    }

    /**
     * start MediaLoader after Player Buffer position >= {@link ListPlayerController#BUFFER_POSITION}
     *
     * @param position RecyclerView item AdapterPosition
     * @param buffer   Player Buffer position
     */
    public void updateBufferPosition(int position, long buffer) {
        if(!mIsPreloading && position == mCurrentPosition && buffer >= BUFFER_POSITION){
            mAliPlayerPreload.moveToSerial(position);
            mIsPreloading = true;
        }
    }

    public void onPageSelected(int position, RecyclerViewAdapter.RecyclerViewHolder viewHolder) {
        mAliPlayerPreload.cancel(position);
        viewHolder.getAliPlayer().start();
    }

    /**
     *  Pause Pre Video when Slide to half the screen
     */
    public void onPageHideHalf(int position, RecyclerViewAdapter.RecyclerViewHolder viewHolder) {
        viewHolder.getAliPlayer().pause();
    }

    public void onPageRelease(int position, RecyclerViewAdapter.RecyclerViewHolder viewHolder) {
        viewHolder.getAliPlayer().stop();
    }

    public void destroy() {
        isOnCreate = false;
        AliPlayerPool.release();
    }
}
