package com.aliyun.videolistbyplayer;

import androidx.appcompat.app.AppCompatActivity;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;

import android.os.Bundle;
import android.view.View;
import com.aliyun.player.bean.InfoBean;
import com.aliyun.player.bean.InfoCode;
import com.aliyun.videolistbyplayer.adapter.CustomLayoutManager;
import com.aliyun.videolistbyplayer.adapter.RecyclerViewAdapter;
import com.aliyun.videolistbyplayer.bean.ListVideoBean;
import com.aliyun.videolistbyplayer.listener.PlayerListener;

import java.util.LinkedList;

public class VideoListActivity extends AppCompatActivity implements CustomLayoutManager.OnViewPagerListener, PlayerListener {

    private RecyclerView mRecyclerView;
    private ListPlayerController mController;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);

        setTheme(R.style.NoActionTheme);
        setContentView(R.layout.activity_video_list);
        mController = new ListPlayerController(this);
        initRecyclerView();
    }

    private void initRecyclerView() {
        mRecyclerView = findViewById(R.id.recyclerview);

        mRecyclerView.setHasFixedSize(true);
        mRecyclerView.setItemAnimator(null);
        mRecyclerView.setDrawingCacheEnabled(true);
        mRecyclerView.setDrawingCacheQuality(View.DRAWING_CACHE_QUALITY_HIGH);
        RecyclerViewAdapter mRecyclerViewAdapter = new RecyclerViewAdapter(this);
        CustomLayoutManager mCustomLayoutManager = new CustomLayoutManager(this, LinearLayoutManager.VERTICAL, false);
        mCustomLayoutManager.setItemPrefetchEnabled(true);
        mCustomLayoutManager.setPreloadItemCount(1);
        mCustomLayoutManager.setOnViewPagerListener(this);
        mRecyclerView.setLayoutManager(mCustomLayoutManager);
        mRecyclerView.setAdapter(mRecyclerViewAdapter);

        LinkedList<ListVideoBean> data = mController.getData();
        mRecyclerViewAdapter.setData(data);
        mRecyclerViewAdapter.setOnPlayerListener(this);
    }

    @Override
    public void onPageShow(int position) {
    }

    @Override
    public void onPageSelected(int position) {
        mController.changeSource(position);
        RecyclerViewAdapter.RecyclerViewHolder viewHolder = getViewHolderByPosition(position);
        if (viewHolder != null) {
            mController.onPageSelected(position,viewHolder);
        }
    }

    @Override
    public void onPageHideHalf(int position) {
        RecyclerViewAdapter.RecyclerViewHolder viewHolder = getViewHolderByPosition(position);
        if (viewHolder != null) {
            mController.onPageHideHalf(position,viewHolder);
        }
    }

    @Override
    public void onPageRelease(int position) {
        RecyclerViewAdapter.RecyclerViewHolder viewHolder = getViewHolderByPosition(position);
        if (viewHolder != null) {
            mController.onPageRelease(position,viewHolder);
        }
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
        mController.destroy();
    }

    /**
     * Player Listener onPrepared
     */
    @Override
    public void onPrepared(int position) {
        RecyclerViewAdapter.RecyclerViewHolder viewHolder = getViewHolderByPosition(position);
        if(viewHolder != null){
            mController.onPrepared(position,viewHolder);
        }
    }

    /**
     * Player Listener onInfo
     */
    @Override
    public void onInfo(int position, InfoBean infoBean) {
        if (infoBean.getCode() == InfoCode.BufferedPosition) {
            long buffer = infoBean.getExtraValue();
            mController.updateBufferPosition(position, buffer);
        }
    }

    @Override
    public void onPlayStateChanged(int position, boolean isPaused) {

    }

    private RecyclerViewAdapter.RecyclerViewHolder getViewHolderByPosition(int position){
        return (RecyclerViewAdapter.RecyclerViewHolder) mRecyclerView.findViewHolderForAdapterPosition(position);
    }
}