package com.aliyun.videolistbyplayer.adapter;

import android.content.Context;
import android.view.LayoutInflater;
import android.view.TextureView;
import android.view.View;
import android.view.ViewGroup;
import android.widget.FrameLayout;

import androidx.annotation.NonNull;
import androidx.recyclerview.widget.RecyclerView;

import com.aliyun.player.AliPlayer;
import com.aliyun.player.bean.InfoBean;
import com.aliyun.videolistbyplayer.R;
import com.aliyun.videolistbyplayer.bean.AliyunRenderView;
import com.aliyun.videolistbyplayer.bean.ListVideoBean;
import com.aliyun.videolistbyplayer.listener.PlayerListener;
import com.aliyun.videolistbyplayer.player.AliPlayerPool;

import java.util.List;

public class RecyclerViewAdapter extends RecyclerView.Adapter<RecyclerViewAdapter.RecyclerViewHolder> {
    private List<ListVideoBean> mData;
    private PlayerListener mOnPlayerListener;

    public RecyclerViewAdapter(Context context) {
        AliPlayerPool.init(context);
    }

    public void setData(List<ListVideoBean> data) {
        this.mData = data;
        notifyDataSetChanged();
    }

    @Override
    public void onViewAttachedToWindow(@NonNull RecyclerViewAdapter.RecyclerViewHolder holder) {
        super.onViewAttachedToWindow(holder);
        holder.bindUrl();
    }

    @NonNull
    @Override
    public RecyclerViewHolder onCreateViewHolder(ViewGroup parent, int viewType) {
        View inflate = LayoutInflater.from(parent.getContext()).inflate(R.layout.layout_recycler_view_item, parent, false);
        return new RecyclerViewHolder(inflate);
    }

    @Override
    public int getItemViewType(int position) {
        return position % AliPlayerPool.TOTAL_SIZE;
    }

    @Override
    public void onBindViewHolder(RecyclerViewAdapter.RecyclerViewHolder holder, int position) {
    }

    @Override
    public int getItemCount() {
        return mData == null ? 0 : mData.size();
    }


    public class RecyclerViewHolder extends RecyclerView.ViewHolder {


        private final FrameLayout mFrameLayout;
        private final AliyunRenderView mAliyunRenderView;

        public RecyclerViewHolder(View itemView) {
            super(itemView);

            mFrameLayout = itemView.findViewById(R.id.framelayout);

            mAliyunRenderView = AliPlayerPool.getPlayer();
            mAliyunRenderView.setOnPlayerListener(new PlayerListener() {
                @Override
                public void onPrepared(int position) {
                    if (mOnPlayerListener != null) {
                        mOnPlayerListener.onPrepared(getAdapterPosition());
                    }
                }

                @Override
                public void onInfo(int position, InfoBean infoBean) {
                    if (mOnPlayerListener != null) {
                        mOnPlayerListener.onInfo(getAdapterPosition(), infoBean);
                    }
                }

                @Override
                public void onPlayStateChanged(int position, boolean isPaused) {
                    if (mOnPlayerListener != null) {
                        mOnPlayerListener.onPlayStateChanged(getAdapterPosition(), isPaused);
                    }
                }
            });
        }

        public AliPlayer getAliPlayer() {
            return mAliyunRenderView.getAliPlayer();
        }

        /*
            update video source
         */
        public void bindUrl() {
            TextureView textureView = mAliyunRenderView.initTextureView();
            mFrameLayout.addView(textureView, 0);

            String url = mData.get(getAdapterPosition()).getUrl();
            mAliyunRenderView.bindUrl(url);
        }
    }

    public void setOnPlayerListener(PlayerListener listener) {
        this.mOnPlayerListener = listener;
    }
}
