package com.aliyun.videolistbyplayer.test;

import androidx.appcompat.app.AppCompatActivity;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;

import android.os.Bundle;
import android.view.TextureView;
import android.view.View;
import android.view.ViewGroup;

import com.aliyun.player.AliPlayer;
import com.aliyun.player.bean.InfoCode;
import com.aliyun.player.source.UrlSource;
import com.aliyun.videolistbyplayer.ListPlayerController;
import com.aliyun.videolistbyplayer.R;
import com.aliyun.videolistbyplayer.adapter.CustomLayoutManager;
import com.aliyun.videolistbyplayer.bean.AliyunRenderView;
import com.aliyun.videolistbyplayer.bean.ListVideoBean;
import com.aliyun.videolistbyplayer.player.AliPlayerPreload;

import java.util.LinkedList;

public class SinglePlayTestActivity extends AppCompatActivity implements CustomLayoutManager.OnViewPagerListener {

    private RecyclerView mRecyclerView;
    private ListPlayerController mController;
    private AliyunRenderView mAliyunRenderView;
    private SingleRecyclerViewAdapter.RecyclerViewHolder mPageSelectedViewHolder;
    private AliPlayer mAliPlayer;
    private LinkedList<ListVideoBean> data;
    private AliPlayerPreload mAliPlayerPreload;
    private boolean mHasLoad = false;
    private int mCurrentPosition;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setTheme(R.style.NoActionTheme);
        setContentView(R.layout.activity_single_play_test);

        mAliPlayerPreload = AliPlayerPreload.getInstance();
        mAliyunRenderView = new AliyunRenderView(this);
        mController = new ListPlayerController(this);
        initRecyclerView();
        initPlayerListener();
    }

    private void initRecyclerView() {
        mRecyclerView = findViewById(R.id.recyclerview);
        mRecyclerView.setHasFixedSize(true);
        mRecyclerView.setItemAnimator(null);
        mRecyclerView.setDrawingCacheEnabled(true);
        mRecyclerView.setDrawingCacheQuality(View.DRAWING_CACHE_QUALITY_HIGH);
        SingleRecyclerViewAdapter mRecyclerViewAdapter = new SingleRecyclerViewAdapter(this);
        CustomLayoutManager mCustomLayoutManager = new CustomLayoutManager(this, LinearLayoutManager.VERTICAL, false);
        mCustomLayoutManager.setItemPrefetchEnabled(true);
        mCustomLayoutManager.setPreloadItemCount(1);
        mCustomLayoutManager.setOnViewPagerListener(this);
        mRecyclerView.setLayoutManager(mCustomLayoutManager);
        mRecyclerView.setAdapter(mRecyclerViewAdapter);

        data = mController.getData();
        mRecyclerViewAdapter.setData(data);
    }

    private void initPlayerListener() {
        mAliyunRenderView.getAliPlayer().setOnInfoListener(infoBean -> {
            if (infoBean.getCode() == InfoCode.BufferedPosition) {
                long extraValue = infoBean.getExtraValue();
                if(extraValue >= 5000 && !mHasLoad){
                    mAliPlayerPreload.moveToSerial(mCurrentPosition);
                    mHasLoad = true;
                }
            }
        });
    }

    @Override
    public void onPageShow(int position) {
    }

    @Override
    public void onPageSelected(int position) {
        this.mCurrentPosition = position;
        mRecyclerView.post(() -> {
            mPageSelectedViewHolder = (SingleRecyclerViewAdapter.RecyclerViewHolder) mRecyclerView.findViewHolderForAdapterPosition(position);
            addTextureView();
            changeDataSource(position);
        });

    }

    @Override
    public void onPageRelease(int position) {
    }

    @Override
    public void onPageHideHalf(int position) {

    }

    private void addTextureView() {
        TextureView textureView = mAliyunRenderView.getTextureView();
        if (textureView.getParent() != null) {
            ((ViewGroup) textureView.getParent()).removeView(textureView);
        }
        mPageSelectedViewHolder.getConvertView().addView(textureView);
    }

    private void changeDataSource(int position) {
        if (mAliPlayer == null) {
            mAliPlayer = mAliyunRenderView.getAliPlayer();
            mAliPlayer.setAutoPlay(true);
        }

        UrlSource urlSource = new UrlSource();
        urlSource.setUri(data.get(position).getUrl());
        mAliPlayer.setDataSource(urlSource);
        mAliPlayer.prepare();
        mAliPlayerPreload.cancel(position);
        mHasLoad = false;
    }
}